==> spip_4.0.4.orig.tar.xz: plugins-dist/dump/lang/dump_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=eo
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucune_donnee' => 'malplena',
	'avis_probleme_ecriture_fichier' => 'Scribproblemo en dosiero @fichier@',

	// B
	'bouton_restaurer_base' => 'Restaŭri la datenbazon',

	// C
	'confirmer_ecraser_base' => 'Jes, mi volas anstataŭgi mian datumbazon per tiu ĉi savkopio',
	'confirmer_ecraser_tables_selection' => 'Jes, mi volas anstataŭigi la elektitajn tabelojn per la savkopio',
	'confirmer_supprimer_sauvegarde' => 'Ĉu vi vere volas forigi tiun savkopion ?',

	// D
	'details_sauvegarde' => 'Detaloj de la savkopio :',

	// E
	'erreur_aucune_donnee_restauree' => 'Nenio restaŭrita',
	'erreur_connect_dump' => 'Servilo nomita « @dump@ » jam ekzistas. Bonvolu alinomi ĝin.',
	'erreur_creation_base_sqlite' => 'Ne eblas krei SQLite-datenbazon por la savkopio.',
	'erreur_nom_fichier' => 'Tiu dosiernomo ne eblas.',
	'erreur_restaurer_verifiez' => 'Korektu la eraron por povi restaŭri.',
	'erreur_sauvegarde_deja_en_cours' => 'Jam savkopiante.',
	'erreur_sqlite_indisponible' => 'Ne eblas fari SQLite-savkopion kun via retejgastigo',
	'erreur_table_absente' => 'Tabelo @table@ mankas',
	'erreur_table_donnees_manquantes' => 'Tabelo @table@, datumo mankas',
	'erreur_taille_sauvegarde' => 'La savkopio ŝajne fiaskis. Dosiero @fichier@ malplenas aŭ mankas.',

	// I
	'info_aucune_sauvegarde_trouvee' => 'Neniu savkopio trovita',
	'info_restauration_finie' => 'Farita ! La savkopio @archive@ restaŭriĝis en via retejo. Vi povas',
	'info_restauration_sauvegarde' => 'Restaŭro de la savkopio @archive@',
	'info_sauvegarde' => 'Savkopio',
	'info_sauvegarde_reussi_02' => 'Datenbazo estas konservita en @archive@. Vi povas',
	'info_sauvegarde_reussi_03' => 'reen al paĝo pri mastrumado',
	'info_sauvegarde_reussi_04' => 'de via retejo.',
	'info_selection_sauvegarde' => 'Vi elektis restaŭri la savkopion @fichier@. Tiu ago ne estos nuligebla.',

	// L
	'label_nom_fichier_restaurer' => 'Aŭ indiku la nomon de la restaŭrota dosiero ',
	'label_nom_fichier_sauvegarde' => 'Dosiernomo por la savkopio',
	'label_selectionnez_fichier' => 'Elektu dosieron en la listo',

	// N
	'nb_donnees' => '@nb@ rikordoj',

	// R
	'restauration_en_cours' => 'Restaŭrante',

	// S
	'sauvegarde_en_cours' => 'Savkopiante',
	'sauvegardes_existantes' => 'Ekzistantaj savkopioj',
	'selectionnez_table_a_restaurer' => 'Elektu la restaŭrotajn tabelojn',

	// T
	'texte_admin_tech_01' => 'Tiu opcio ebligas al vi konservi enhavon de bazo en dosiero stokota en dosierujo @dossier@. Ne forgesu ankaŭ reakiri la tuton de la dosierujo @img@, kiu enhavas bildojn kaj dokumentojn uzatajn en artikoloj kaj rubrikoj.',
	'texte_admin_tech_02' => 'Atentu : tiu savkopio povos esti restaŭrita
NUR por retejo starigita per la sama versio de SPIP. Nepre ne " malplenigu la datenbazon " esperante poste reinstali savkopion post ĝisdatigo... Konsultu <a href="@spipnet@">la dokumentaron de SPIP</a>.',
	'texte_restaurer_base' => 'Restaŭri la enhavon de datenbaza savkopio',
	'texte_restaurer_sauvegarde' => 'Tiu opcio ebligas al vi restarigi antaŭe faritan savkopion de la bazo.
  Por tio, la dosiero entenanta la savkopion devas esti lokita
  en la dosierujon @dossier@.
  Estu singardema pri tiu ĉi funkcio : <b>la modifoj, eventualaj perdoj, estas
  neinversigeblaj.</b>',
	'texte_sauvegarde' => 'Konservi la enhavon de la datenbazo',
	'texte_sauvegarde_base' => 'Konservi la datenbazon',
	'tout_restaurer' => 'Restaŭri ĉiujn tabelojn',
	'tout_sauvegarder' => 'Savi ĉiujn tabelojn',

	// U
	'une_donnee' => '1 rikordo'
);

==> spip_4.4.9+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// A
	'aucune_donnee' => 'malplena',
	'avis_probleme_ecriture_fichier' => 'Scribproblemo en dosiero @fichier@',

	// B
	'bouton_restaurer_base' => 'Restaŭri la datenbazon',

	// C
	'confirmer_ecraser_base' => 'Jes, mi volas anstataŭgi mian datumbazon per tiu ĉi savkopio',
	'confirmer_ecraser_tables_selection' => 'Jes, mi volas anstataŭigi la elektitajn tabelojn per la savkopio',
	'confirmer_supprimer_sauvegarde' => 'Ĉu vi vere volas forigi tiun savkopion ?',

	// D
	'details_sauvegarde' => 'Detaloj de la savkopio :',

	// E
	'erreur_aucune_donnee_restauree' => 'Nenio restaŭrita',
	'erreur_connect_dump' => 'Servilo nomita « @dump@ » jam ekzistas. Bonvolu alinomi ĝin.',
	'erreur_creation_base_sqlite' => 'Ne eblas krei SQLite-datenbazon por la savkopio.',
	'erreur_nom_fichier' => 'Tiu dosiernomo ne eblas.',
	'erreur_restaurer_verifiez' => 'Korektu la eraron por povi restaŭri.',
	'erreur_sauvegarde_deja_en_cours' => 'Jam savkopiante.',
	'erreur_sqlite_indisponible' => 'Ne eblas fari SQLite-savkopion kun via retejgastigo',
	'erreur_table_absente' => 'Tabelo @table@ mankas',
	'erreur_table_donnees_manquantes' => 'Tabelo @table@, datumo mankas',
	'erreur_taille_sauvegarde' => 'La savkopio ŝajne fiaskis. Dosiero @fichier@ malplenas aŭ mankas.',

	// I
	'info_aucune_sauvegarde_trouvee' => 'Neniu savkopio trovita',
	'info_restauration_finie' => 'Farita ! La savkopio @archive@ restaŭriĝis en via retejo. Vi povas',
	'info_restauration_sauvegarde' => 'Restaŭro de la savkopio @archive@',
	'info_sauvegarde' => 'Savkopio',
	'info_sauvegarde_reussi_02' => 'Datenbazo estas konservita en @archive@. Vi povas',
	'info_sauvegarde_reussi_03' => 'reen al paĝo pri mastrumado',
	'info_sauvegarde_reussi_04' => 'de via retejo.',
	'info_selection_sauvegarde' => 'Vi elektis restaŭri la savkopion @fichier@. Tiu ago ne estos nuligebla.',

	// L
	'label_nom_fichier_restaurer' => 'Aŭ indiku la nomon de la restaŭrota dosiero ',
	'label_nom_fichier_sauvegarde' => 'Dosiernomo por la savkopio',
	'label_selectionnez_fichier' => 'Elektu dosieron en la listo',

	// N
	'nb_donnees' => '@nb@ rikordoj',

	// R
	'restauration_en_cours' => 'Restaŭrante',

	// S
	'sauvegarde_en_cours' => 'Savkopiante',
	'sauvegardes_existantes' => 'Ekzistantaj savkopioj',
	'selectionnez_table_a_restaurer' => 'Elektu la restaŭrotajn tabelojn',

	// T
	'texte_admin_tech_01' => 'Tiu opcio ebligas al vi konservi enhavon de bazo en dosiero stokota en dosierujo @dossier@. Ne forgesu ankaŭ reakiri la tuton de la dosierujo @img@, kiu enhavas bildojn kaj dokumentojn uzatajn en artikoloj kaj rubrikoj.',
	'texte_admin_tech_02' => 'Atentu : tiu savkopio povos esti restaŭrita
NUR por retejo starigita per la sama versio de SPIP. Nepre ne " malplenigu la datenbazon " esperante poste reinstali savkopion post ĝisdatigo... Konsultu <a href="@spipnet@">la dokumentaron de SPIP</a>.',
	'texte_restaurer_base' => 'Restaŭri la enhavon de datenbaza savkopio',
	'texte_restaurer_sauvegarde' => 'Tiu opcio ebligas al vi restarigi antaŭe faritan savkopion de la bazo.
  Por tio, la dosiero entenanta la savkopion devas esti lokita
  en la dosierujon @dossier@.
  Estu singardema pri tiu ĉi funkcio : <b>la modifoj, eventualaj perdoj, estas
  neinversigeblaj.</b>',
	'texte_sauvegarde' => 'Konservi la enhavon de la datenbazo',
	'texte_sauvegarde_base' => 'Konservi la datenbazon',
	'tout_restaurer' => 'Restaŭri ĉiujn tabelojn',
	'tout_sauvegarder' => 'Savi ĉiujn tabelojn',

	// U
	'une_donnee' => '1 rikordo',
];
